method column in returned data frame is the match for the name in
method_col based on the supplied methods_lu.
bin_method(df, methods_lu, method_col = "method", unassigned = "observed")Dataframe to attribute with the standardised method from the methods_lu.
Dataframe with 'method' column for the original method name and 'method_gp' column for the standardised methods.
Character. Name of column in df with method.
Character. Value for unmatched or NA methods.
Dataframe with standardised method column.