Make standardised collection methods lookup
make_methods_lu(
df,
methods_key,
method_col = "method",
taxonomy,
taxa_col = "original_name",
unassigned = "observed"
)Dataframe with methods variants.
Dataframe with 'method_gp' column for the standardised methods, 'terms' column for the search terms used to define each standard method_gp, and 'rank' column with integers specifying which method_gp to use over others if there is overlap in search terms (where higher numbers indicate those to use over lower numbers).
Character. Name of column in df with method.
List resulting from call to make_taxonomy().
Character. Name of column in df with taxa. Used for matching to taxonomy and generating 'tax_gp'
column in output, indicating which taxonomic groups each method has been recorded for.
Dataframe with original 'method' column and standardised 'method_gp' column based on the supplied methods_key.
Also, 'tax_gp' column indicating the taxonomic group for which the methods were recorded, and
'method_n' column indicating the number of occurrences for the original 'method' in the 'tax_gp'.