R/try_name_via_gbif.R
try_name_via_gbif.RdUseful in cases where the supplied scientific name does not find any match
in the taxonomic source being queried. This function queries the GBIF
Backbone Taxonomy for a supplied scientific name. The scientific
name from any successful match is then queried against
galah::search_taxa().
try_name_via_gbif(name, target_rank)If no match, NULL. If matched, a tibble ready for input to the
overrides argument of make_taxonomy().
galah::search_taxa("Peziza vesiculosa Bull.: Fr.") # Homonym issue
#> Error in check_pour_package(.pkg): No data stored by `potions`
#> ℹ try using `brew()
try_name_via_gbif("Peziza vesiculosa Bull.: Fr.")
#> Error in check_pour_package(.pkg): No data stored by `potions`
#> ℹ try using `brew()